@@ -5,9 +5,8 @@ $filesep ||= '/';
 if (!exists $param{'helpfile'}) {
      $param{'helpfile'} = "$param{miscdir}${filesep}infobot.help";
 }
-$helptopics = "";
 
-if (open (HELP, $param{'miscdir'}.$filesep.$param{'helpfile'})) {
+if (open (HELP, $param{'helpfile'})) {
 	undef %help;
 	while ($help = <HELP>) {
 	$help =~ s/\#.*//;
