@@ -80,6 +80,11 @@ sub process {
     $VerifWho = &verifyUser($nuh);
 
     if ($VerifWho) {
+        if (IsFlag("i") eq "i") {
+             &status("Ignoring $who: $VerifWho");
+             return 'NOREPLY';
+        }
+
 	if ($msgType =~ /private/) {
 	    # it's a private message
 	    my ($potentialPass) = $message =~ /^\s*(\S+)/;
@@ -246,16 +251,28 @@ sub process {
 
     # might want to take this out.
 
-    if ($addressed and $message =~ /^seen (\S+)\?*/) {
+    if ($addressed and $message =~ /^seen (\S+)/) {
 	my $person = $1;
-	if (exists $seen{$person}) {
-	    my $when = localtime($seen{$person});
+	$person =~ s/\?*\s*$//;
+	if ($seen{lc $person}) {
+	    my ($when,$what) = split /$;/, $seen{lc $person};
+	    $when = localtime $when;
+#	    $when = localtime($seen{lc $person});
+	    
 	    if ($msgType =~ /public/) {
-		&performSay("$person was last seen saying something on IRC $when");
+		&performSay("$person was last seen on IRC $when, saying: $what");
 	    } else {
-		&msg($who, "$person was last seen saying something on IRC $when");
+		&msg($who, "$person was last seen on IRC $when, saying: $what");
 	    }
+	    return 'NOREPLY';
 	}
+	
+	if ($msgType =~ /public/) {
+	    &performSay("I haven't seen '$person', $who");
+	} else {
+	    &msg($who,"I haven't seen '$person', $who");
+	}
+	return 'NOREPLY';
     }
 
     if (0 and $message =~ /^timer\s+(\d+)$/i) {
