@@ -98,7 +98,7 @@ sub doStatement {
     } else {
 	if ($param{'acceptUrl'} eq 'REQUIRE') {
 	    # require url type.
-	    &status("REJECTED non-URL entry") if ($param{VERBOSITY});
+#	    &status("REJECTED non-URL entry") if ($param{VERBOSITY});
 	    return 'NOREPLY' if ($theType eq "");
 	} elsif ($param{'acceptUrl'} eq 'REJECT') {
 	    &status("REJECTED URL entry") if ($param{VERBOSITY});
