@@ -88,14 +88,20 @@ sub verifyUser {
     }
 
     my $now = time();
-    $seen{$who} = $now;
+
+    my $m = $message;
+    if ($msgType !~ /public/) {
+	$m = "<private message>";
+    }
+    $seen{lc $who} = $now.$;.$m;
 
     if ($VerifWho) {
 	$uFlags = $user{$VerifWho."flags"};
 	$uPasswd = $user{$VerifWho."pass"};
 	$uTitle = $user{$VerifWho."title"};
 
-	if (not exists $seenVerif{$VerifWho} or time()-$seenVerif{$VerifWho} > 360) {
+	if (exists $seenVerif{$VerifWho} or 
+	    (time()-$seenVerif{$VerifWho} > 360)) {
 	    status("mask verified for $VerifWho");
 	}
 
@@ -302,6 +308,8 @@ sub userProcessing {
 		    } 
 		    &rawout("QUIT :$who");
 		    &closeDBM("is", "are");
+		    if (%seen) { dbmclose %seen }
+		    if (%plusplus) { dbmclose %plusplus }
 		    status("Dying by $who\'s request");
 		    exit(0);
 		}
